==> 0.0.5.tar.gz: lib/hyperkyc_api_base_response.dart <==
import 'hyperkyc_flutter_constants.dart';

/// BaseResponse is not used anywhere currently
class BaseResponse {
  /// Metadata contains data like TransactionId, RequestId, Attempts count, etc
  final Metadata? metadata;

  /// Status received after Hyperverge API call
  final String? status;

  /// StatusCode received after Hyperverge API call
  final String? statusCode;

  /// Constructor
  BaseResponse({
    this.metadata,
    this.status,
    this.statusCode,
  });

  /// Convert BaseResponse object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.metadata: this.metadata,
      HyperKycConstants.status: this.status,
      HyperKycConstants.statusCode: this.statusCode,
    };
  }

  /// Convert Map to BaseResponse object
  factory BaseResponse.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return BaseResponse();
    }
    return BaseResponse(
      metadata: map[HyperKycConstants.metadata] as Metadata,
      status: map[HyperKycConstants.status] as String,
      statusCode: (map[HyperKycConstants.statusCode] ?? '').toString(),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'BaseResponse{metadata: $metadata, status: $status, statusCode: $statusCode}';
  }
}

/// Metadata holds the metadata received/present in Hyperverge API calls
class Metadata {
  /// Data
  final String? data;

  /// CustomerId
  final String? customerId;

  /// RequestId
  final String? requestId;

  /// TransactionId
  final String? transactionId;

  /// AttemptCount
  final String? attemptCount;

  /// Constructor
  Metadata({
    this.data,
    this.customerId,
    this.requestId,
    this.transactionId,
    this.attemptCount,
  });

  /// Convert Metadata object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.data: this.data,
      HyperKycConstants.customerId: this.customerId,
      HyperKycConstants.requestId: this.requestId,
      HyperKycConstants.transactionId: this.transactionId,
      HyperKycConstants.attemptCount: this.attemptCount,
    };
  }

  /// Convert Map to Metadata object
  factory Metadata.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Metadata();
    }
    return Metadata(
      data: map[HyperKycConstants.data] as String?,
      customerId: map[HyperKycConstants.customerId] as String?,
      requestId: map[HyperKycConstants.requestId] as String?,
      transactionId: map[HyperKycConstants.transactionId] as String?,
      attemptCount: (map[HyperKycConstants.attemptCount] ?? '').toString(),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'Metadata{data: $data, customerId: $customerId, requestId: $requestId, transactionId: $transactionId, attemptCount: $attemptCount}';
  }
}

/// Summary holds summary received from Hyperverge API calls
class Summary {
  /// Action : pass / manualReview / fail
  final String? action;

  /// List of Details present in Summary
  final List<Details?>? details;

  /// Constructor
  Summary({
    this.action,
    this.details,
  });

  /// Convert Summary object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.action: this.action,
      HyperKycConstants.details: this.details,
    };
  }

  /// Convert Map to Summary object
  factory Summary.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Summary();
    }
    List<Details> detailsList = List.empty(growable: true);
    List detailsListFromMap = map[HyperKycConstants.details] ?? {};
    for (var detailMap in detailsListFromMap) {
      Details details = Details.fromMap(detailMap ?? {});
      detailsList.add(details);
    }
    return Summary(
      action: map[HyperKycConstants.action] as String?,
      details: detailsList,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'Summary{action: $action, details: $details}';
  }
}

/// Details holds the details present in Summary object
class Details {
  /// Code
  final String? code;

  /// Message
  final String? message;

  /// Constructor
  Details({
    this.code,
    this.message,
  });

  /// Convert Details object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.code: this.code,
      HyperKycConstants.message: this.message,
    };
  }

  /// Convert Map to Details object
  factory Details.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Details();
    }
    return Details(
      code: map[HyperKycConstants.code] as String?,
      message: map[HyperKycConstants.message] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'Details{code: $code, message: $message}';
  }
}

/// Fieldvalue is a generic object which holds the following properties obtained from Hyperverge API calls
class Fieldvalue {
  /// Value
  final String? value;

  /// Confidence
  final String? confidence;

  /// Confidence score
  final String? score;

  /// Is review needed or not
  final String? reviewNeeded;

  /// Constructor
  Fieldvalue({
    this.value,
    this.confidence,
    this.score,
    this.reviewNeeded,
  });

  /// Convert Fieldvalue object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.value: this.value,
      HyperKycConstants.confidence: this.confidence,
      HyperKycConstants.score: this.score,
      HyperKycConstants.reviewNeeded: this.reviewNeeded,
    };
  }

  /// Convert map to Fieldvalue object
  factory Fieldvalue.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Fieldvalue();
    }
    return Fieldvalue(
      value: map[HyperKycConstants.value] as String?,
      confidence: map[HyperKycConstants.confidence] as String?,
      score: map[HyperKycConstants.score] as String?,
      reviewNeeded: (map[HyperKycConstants.reviewNeeded] ?? '').toString(),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'Fieldvalue{value: $value, confidence: $confidence, score: $score, reviewNeeded: $reviewNeeded}';
  }
}

==> 0.2.0.tar.gz: lib/hyperkyc_api_base_response.dart <==
import 'hyperkyc_flutter_constants.dart';

/// [BaseResponse] is not used anywhere currently
class BaseResponse {
  /// [metadata] contains data like TransactionId, RequestId, Attempts count, etc
  final Metadata? metadata;

  /// [status] received after Hyperverge API call
  final String? status;

  /// [statusCode] received after Hyperverge API call
  final String? statusCode;

  /// Constructor
  BaseResponse({
    this.metadata,
    this.status,
    this.statusCode,
  });

  /// Convert BaseResponse object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.metadata: this.metadata,
      HyperKycConstants.status: this.status,
      HyperKycConstants.statusCode: this.statusCode,
    };
  }

  /// Convert Map to BaseResponse object
  factory BaseResponse.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return BaseResponse();
    }
    return BaseResponse(
      metadata: map[HyperKycConstants.metadata] as Metadata,
      status: map[HyperKycConstants.status] as String,
      statusCode: (map[HyperKycConstants.statusCode] ?? '').toString(),
    );
  }

  /// Overriden [toString] method
  @override
  String toString() {
    return 'BaseResponse{metadata: $metadata, status: $status, statusCode: $statusCode}';
  }
}

/// [Metadata] holds the metadata received/present in Hyperverge API calls
class Metadata {
  /// [data]
  final String? data;

  /// [customerId]
  final String? customerId;

  /// [requestId]
  final String? requestId;

  /// [transactionId]
  final String? transactionId;

  /// [attemptCount]
  final String? attemptCount;

  /// Constructor
  Metadata({
    this.data,
    this.customerId,
    this.requestId,
    this.transactionId,
    this.attemptCount,
  });

  /// Convert Metadata object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.data: this.data,
      HyperKycConstants.customerId: this.customerId,
      HyperKycConstants.requestId: this.requestId,
      HyperKycConstants.transactionId: this.transactionId,
      HyperKycConstants.attemptCount: this.attemptCount,
    };
  }

  /// Convert Map to Metadata object
  factory Metadata.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Metadata();
    }
    return Metadata(
      data: map[HyperKycConstants.data] as String?,
      customerId: map[HyperKycConstants.customerId] as String?,
      requestId: map[HyperKycConstants.requestId] as String?,
      transactionId: map[HyperKycConstants.transactionId] as String?,
      attemptCount: (map[HyperKycConstants.attemptCount] ?? '').toString(),
    );
  }

  /// Overriden [toString] method
  @override
  String toString() {
    return 'Metadata{data: $data, customerId: $customerId, requestId: $requestId, transactionId: $transactionId, attemptCount: $attemptCount}';
  }
}

/// [Summary] holds summary received from Hyperverge API calls
class Summary {
  /// [action] : pass / manualReview / fail
  final String? action;

  /// List of Details [details] present in Summary
  final List<Details?>? details;

  /// Constructor
  Summary({
    this.action,
    this.details,
  });

  /// Convert Summary object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.action: this.action,
      HyperKycConstants.details: this.details,
    };
  }

  /// Convert Map to Summary object
  factory Summary.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Summary();
    }
    List<Details> detailsList = List.empty(growable: true);
    List detailsListFromMap = map[HyperKycConstants.details] ?? {};
    for (var detailMap in detailsListFromMap) {
      Details details = Details.fromMap(detailMap ?? {});
      detailsList.add(details);
    }
    return Summary(
      action: map[HyperKycConstants.action] as String?,
      details: detailsList,
    );
  }

  /// Overriden [toString] method
  @override
  String toString() {
    return 'Summary{action: $action, details: $details}';
  }
}

/// [Details] holds the details present in Summary object
class Details {
  /// [code]
  final String? code;

  /// [message]
  final String? message;

  /// Constructor
  Details({
    this.code,
    this.message,
  });

  /// Convert Details object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.code: this.code,
      HyperKycConstants.message: this.message,
    };
  }

  /// Convert Map to Details object
  factory Details.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Details();
    }
    return Details(
      code: map[HyperKycConstants.code] as String?,
      message: map[HyperKycConstants.message] as String?,
    );
  }

  /// Overriden [toString] method
  @override
  String toString() {
    return 'Details{code: $code, message: $message}';
  }
}

/// [Fieldvalue] is a generic object which holds the following properties obtained from Hyperverge API calls
class Fieldvalue {
  /// [value]
  final String? value;

  /// [confidence]
  final String? confidence;

  /// Confidence [score]
  final String? score;

  /// Is review needed or not
  final String? reviewNeeded;

  /// Constructor
  Fieldvalue({
    this.value,
    this.confidence,
    this.score,
    this.reviewNeeded,
  });

  /// Convert Fieldvalue object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.value: this.value,
      HyperKycConstants.confidence: this.confidence,
      HyperKycConstants.score: this.score,
      HyperKycConstants.reviewNeeded: this.reviewNeeded,
    };
  }

  /// Convert map to Fieldvalue object
  factory Fieldvalue.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return Fieldvalue();
    }
    return Fieldvalue(
      value: map[HyperKycConstants.value] as String?,
      confidence: map[HyperKycConstants.confidence] as String?,
      score: map[HyperKycConstants.score] as String?,
      reviewNeeded: (map[HyperKycConstants.reviewNeeded] ?? '').toString(),
    );
  }

  /// Overriden [toString] method
  @override
  String toString() {
    return 'Fieldvalue{value: $value, confidence: $confidence, score: $score, reviewNeeded: $reviewNeeded}';
  }
}
